-------------------------------------------------------------------------------
-- Title      : mityarm_5csx_dev_board_top
-- Project    : 
-------------------------------------------------------------------------------
--
--     o  0                          
--     | /       Copyright (c) 2013
--    (CL)---o   Critical Link, LLC  
--      \                            
--       O                           
--
-- File       : mityarm-5csx_dev_board_top.vhd
-- Company    : Critical Link, LLC
-- Created    : 2013-07-29
-- Last update: 2013-09-11
-- Standard   : VHDL'93/02
-------------------------------------------------------------------------------
-- Description: Top level entity for the MityARM-5CSX Development Board
-------------------------------------------------------------------------------
-- Copyright (c) 2013 Critical Link, LLC
-------------------------------------------------------------------------------
-- Revisions  :
-- Date			Version	Author	Description
-- 2013-07-28	0.1		Dan V		Initial
-- 2013-09-11	0.2		Dan V		Base Dev Board with probes for Full HSMC
--											Loopback
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

-------------------------------------------------------------------------------

entity mityarm_5csx_dev_board_top is
	port 
	(
		-- HPS DDR
		HPS_DDR_A			: out   std_logic_vector(14 downto 0);
		HPS_DDR_BAS			: out   std_logic_vector(2 downto 0);
		HPS_DDR_CK_P		: out   std_logic;
		HPS_DDR_CK_N		: out   std_logic;
		HPS_DDR_CKE			: out   std_logic;
		HPS_DDR_CS0_N		: out   std_logic;
		HPS_DDR_RAS_N		: out   std_logic;
		HPS_DDR_CAS_N		: out   std_logic;
		HPS_DDR_WE_N		: out   std_logic;
		HPS_DDR_RESET_N	: out   std_logic;
		HPS_DDR_D			: inout std_logic_vector(39 downto 0) := (others => 'X');
		HPS_DDR_DQS_P		: inout std_logic_vector(4 downto 0)  := (others => 'X');
		HPS_DDR_DQS_N		: inout std_logic_vector(4 downto 0)  := (others => 'X');
		HPS_DDR_DQM			: out   std_logic_vector(4 downto 0);
		HPS_RZQ0				: in    std_logic                     := 'X';
		HPS_ODT				: out std_logic;
		-- RGMII1
		RGMII1_TX_CLK		: out   std_logic;
		RGMII1_TXD0			: out   std_logic;
		RGMII1_TXD1			: out   std_logic;
		RGMII1_TXD2			: out   std_logic;
		RGMII1_TXD3			: out   std_logic;
		RGMII1_RXD0			: in    std_logic                     := 'X';
		RGMII1_MDIO			: inout std_logic                     := 'X';
		RGMII1_MDC			: out   std_logic;
		RGMII1_RX_CTL		: in    std_logic                     := 'X';
		RGMII1_TX_CTL		: out   std_logic;
		RGMII1_RX_CLK		: in    std_logic                     := 'X';
		RGMII1_RXD1			: in    std_logic                     := 'X';
		RGMII1_RXD2			: in    std_logic                     := 'X';
		RGMII1_RXD3			: in    std_logic                     := 'X';
		RGMII1_RESETn		: inout	std_logic;
		-- QSPI
		QSPI_DQ0				: inout std_logic                     := 'X';
		QSPI_DQ1				: inout std_logic                     := 'X';
		QSPI_DQ2				: inout std_logic                     := 'X';
		QSPI_DQ3				: inout std_logic                     := 'X';
		QSPI_SS0				: out   std_logic;
		QSPI_SS1				: out   std_logic;
		QSPI_CLK				: out   std_logic;
		-- SDMMC
		SDMMC_CMD			: inout std_logic                     := 'X';
		SDMMC_D0				: inout std_logic                     := 'X';
		SDMMC_D1				: inout std_logic                     := 'X';
		SDMMC_CLK			: out   std_logic;
		SDMMC_D2				: inout std_logic                     := 'X';
		SDMMC_D3				: inout std_logic                     := 'X';
		-- USB1
		USB1_ULPI_D0		: inout std_logic                     := 'X';
		USB1_ULPI_D1		: inout std_logic                     := 'X';
		USB1_ULPI_D2		: inout std_logic                     := 'X';
		USB1_ULPI_D3		: inout std_logic                     := 'X';
		USB1_ULPI_D4		: inout std_logic                     := 'X';
		USB1_ULPI_D5		: inout std_logic                     := 'X';
		USB1_ULPI_D6		: inout std_logic                     := 'X';
		USB1_ULPI_D7		: inout std_logic                     := 'X';
		USB1_ULPI_CLK		: in    std_logic                     := 'X';
		USB1_ULPI_STP		: out   std_logic;
		USB1_ULPI_DIR		: in    std_logic                     := 'X';
		USB1_ULPI_NXT		: in    std_logic                     := 'X';
		USB1_ULPI_CS		: inout std_logic;
		USB1_ULPI_RESET_N	: inout std_logic;
		-- UART0
		B7A_UART0_RX		: in    std_logic                     := 'X';
		B7A_UART0_TX		: out   std_logic;
		-- I2C0
		B7A_I2C0_SDA		: inout std_logic                     := 'X';
		B7A_I2C0_SCL		: inout std_logic                     := 'X';
		-- CAN0
		B7A_CAN0_RX			: in    std_logic                     := 'X';             
		B7A_CAN0_TX			: out   std_logic;                                        
		-- CAN1
		B7A_CAN1_RX			: in    std_logic                     := 'X';            
		B7A_CAN1_TX			: out   std_logic;
		-- I2C1
		I2C1_SCL          : inout std_logic;
		I2C1_SDA          : inout std_logic;
		-- LEDs
		LED1              : inout std_logic;
		LED2              : inout std_logic;
		LED3              : inout std_logic;
		-- Switches
		SW1               : inout std_logic;
		SW2               : inout std_logic;
		SW3               : inout std_logic;
		
		-- HSMC1
		HSMC1_SMSDA			: in std_logic;
		HSMC1_SMSCL			: out   std_logic;
		 
		HSMC1_CLKOUT0 		: out   std_logic;
		HSMC1_CLKOUT1		: out   std_logic;
		HSMC1_CLKOUT2		: out   std_logic;
		HSMC1_CLKIN0		: in    std_logic;
		HSMC1_CLKIN1		: in    std_logic;
		HSMC1_CLKIN2		: in    std_logic;
		
		HSMC1_CLKOUT1_N	: out   std_logic;
		HSMC1_CLKOUT2_N	: out   std_logic;
		HSMC1_CLKIN1_N		: in    std_logic;
		HSMC1_CLKIN2_N		: in    std_logic;
		
		HSMC1_PRSNTn		: in    std_logic;
		
		HSMC1_D0				: out std_logic;
		HSMC1_D1				: in std_logic;
		HSMC1_D2				: out std_logic;
		HSMC1_D3				: in std_logic;
		
		HSMC1_TX0			: out   std_logic;
		HSMC1_TX1			: out   std_logic;
		HSMC1_TX2			: out   std_logic;
		HSMC1_TX3			: out   std_logic;
		HSMC1_TX4			: out   std_logic;
		HSMC1_TX5			: out   std_logic;
		HSMC1_TX6			: out   std_logic;
		HSMC1_TX7			: out   std_logic;
		HSMC1_TX8			: out   std_logic;
		HSMC1_TX9			: out   std_logic;
		HSMC1_TX10			: out   std_logic;
		HSMC1_TX11			: out   std_logic;
		HSMC1_TX12			: out   std_logic;
		HSMC1_TX13			: out   std_logic;
		HSMC1_TX14			: out   std_logic;
		HSMC1_TX15			: out   std_logic;
		HSMC1_TX16			: out   std_logic;

		HSMC1_TX0_N			: out   std_logic;
		HSMC1_TX1_N			: out   std_logic;
		HSMC1_TX2_N			: out   std_logic;
		HSMC1_TX3_N			: out   std_logic;
		HSMC1_TX4_N			: out   std_logic;
		HSMC1_TX5_N			: out   std_logic;
		HSMC1_TX6_N			: out   std_logic;
		HSMC1_TX7_N			: out   std_logic;
		HSMC1_TX8_N			: out   std_logic;
		HSMC1_TX9_N			: out   std_logic;
		HSMC1_TX10_N		: out   std_logic;
		HSMC1_TX11_N		: out   std_logic;
		HSMC1_TX12_N		: out   std_logic;
		HSMC1_TX13_N		: out   std_logic;
		HSMC1_TX14_N		: out   std_logic;
		HSMC1_TX15_N		: out   std_logic;
		HSMC1_TX16_N		: out   std_logic;
		

		HSMC1_RX0			: in    std_logic;
		HSMC1_RX1			: in    std_logic;
		HSMC1_RX2			: in    std_logic;
		HSMC1_RX3			: in    std_logic;
		HSMC1_RX4			: in    std_logic;
		HSMC1_RX5			: in    std_logic;
		HSMC1_RX6			: in    std_logic;
		HSMC1_RX7			: in    std_logic;
		HSMC1_RX8			: in    std_logic;
		HSMC1_RX9			: in    std_logic;
		HSMC1_RX10			: in    std_logic;
		HSMC1_RX11			: in    std_logic;
		HSMC1_RX12			: in    std_logic;
		HSMC1_RX13			: in    std_logic;
		HSMC1_RX14			: in    std_logic;
		HSMC1_RX15			: in    std_logic;
		HSMC1_RX16			: in    std_logic;
		
		HSMC1_RX0_N			: in    std_logic;
		HSMC1_RX1_N			: in    std_logic;
		HSMC1_RX2_N			: in    std_logic;
		HSMC1_RX3_N			: in    std_logic;
		HSMC1_RX4_N			: in    std_logic;
		HSMC1_RX5_N			: in    std_logic;
		HSMC1_RX6_N			: in    std_logic;
		HSMC1_RX7_N			: in    std_logic;
		HSMC1_RX8_N			: in    std_logic;
		HSMC1_RX9_N			: in    std_logic;
		HSMC1_RX10_N		: in    std_logic;
		HSMC1_RX11_N		: in    std_logic;
		HSMC1_RX12_N		: in    std_logic;
		HSMC1_RX13_N		: in    std_logic;
		HSMC1_RX14_N		: in    std_logic;
		HSMC1_RX15_N		: in    std_logic;
		HSMC1_RX16_N		: in    std_logic
);

end entity mityarm_5csx_dev_board_top;

-------------------------------------------------------------------------------

architecture rtl of mityarm_5csx_dev_board_top is
	component mityarm_5csx_dev_board is
		port (
			hps_ddr_mem_a                    : out   std_logic_vector(14 downto 0);                    -- mem_a
			hps_ddr_mem_ba                   : out   std_logic_vector(2 downto 0);                     -- mem_ba
			hps_ddr_mem_ck                   : out   std_logic;                                        -- mem_ck
			hps_ddr_mem_ck_n                 : out   std_logic;                                        -- mem_ck_n
			hps_ddr_mem_cke                  : out   std_logic;                                        -- mem_cke
			hps_ddr_mem_cs_n                 : out   std_logic;                                        -- mem_cs_n
			hps_ddr_mem_ras_n                : out   std_logic;                                        -- mem_ras_n
			hps_ddr_mem_cas_n                : out   std_logic;                                        -- mem_cas_n
			hps_ddr_mem_we_n                 : out   std_logic;                                        -- mem_we_n
			hps_ddr_mem_reset_n              : out   std_logic;                                        -- mem_reset_n
			hps_ddr_mem_dq                   : inout std_logic_vector(39 downto 0) := (others => 'X'); -- mem_dq
			hps_ddr_mem_dqs                  : inout std_logic_vector(4 downto 0)  := (others => 'X'); -- mem_dqs
			hps_ddr_mem_dqs_n                : inout std_logic_vector(4 downto 0)  := (others => 'X'); -- mem_dqs_n
			hps_ddr_mem_odt                  : out   std_logic;                                        -- mem_odt
			hps_ddr_mem_dm                   : out   std_logic_vector(4 downto 0);                     -- mem_dm
			hps_ddr_oct_rzqin                : in    std_logic                     := 'X';             -- oct_rzqin
			hps_io_hps_io_emac1_inst_TX_CLK : out   std_logic;                                        -- hps_io_emac1_inst_TX_CLK
			hps_io_hps_io_emac1_inst_TXD0   : out   std_logic;                                        -- hps_io_emac1_inst_TXD0
			hps_io_hps_io_emac1_inst_TXD1   : out   std_logic;                                        -- hps_io_emac1_inst_TXD1
			hps_io_hps_io_emac1_inst_TXD2   : out   std_logic;                                        -- hps_io_emac1_inst_TXD2
			hps_io_hps_io_emac1_inst_TXD3   : out   std_logic;                                        -- hps_io_emac1_inst_TXD3
			hps_io_hps_io_emac1_inst_RXD0   : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD0
			hps_io_hps_io_emac1_inst_MDIO   : inout std_logic                     := 'X';             -- hps_io_emac1_inst_MDIO
			hps_io_hps_io_emac1_inst_MDC    : out   std_logic;                                        -- hps_io_emac1_inst_MDC
			hps_io_hps_io_emac1_inst_RX_CTL : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RX_CTL
			hps_io_hps_io_emac1_inst_TX_CTL : out   std_logic;                                        -- hps_io_emac1_inst_TX_CTL
			hps_io_hps_io_emac1_inst_RX_CLK : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RX_CLK
			hps_io_hps_io_emac1_inst_RXD1   : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD1
			hps_io_hps_io_emac1_inst_RXD2   : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD2
			hps_io_hps_io_emac1_inst_RXD3   : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD3
			hps_io_hps_io_qspi_inst_SS1     : out   std_logic;                                        -- hps_io_qspi_inst_SS1
			hps_io_hps_io_qspi_inst_IO0     : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO0
			hps_io_hps_io_qspi_inst_IO1     : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO1
			hps_io_hps_io_qspi_inst_IO2     : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO2
			hps_io_hps_io_qspi_inst_IO3     : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO3
			hps_io_hps_io_qspi_inst_SS0     : out   std_logic;                                        -- hps_io_qspi_inst_SS0
			hps_io_hps_io_qspi_inst_CLK     : out   std_logic;                                        -- hps_io_qspi_inst_CLK
			hps_io_hps_io_sdio_inst_CMD     : inout std_logic                     := 'X';             -- hps_io_sdio_inst_CMD
			hps_io_hps_io_sdio_inst_D0      : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D0
			hps_io_hps_io_sdio_inst_D1      : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D1
			hps_io_hps_io_sdio_inst_CLK     : out   std_logic;                                        -- hps_io_sdio_inst_CLK
			hps_io_hps_io_sdio_inst_D2      : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D2
			hps_io_hps_io_sdio_inst_D3      : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D3
			hps_io_hps_io_usb1_inst_D0      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D0
			hps_io_hps_io_usb1_inst_D1      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D1
			hps_io_hps_io_usb1_inst_D2      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D2
			hps_io_hps_io_usb1_inst_D3      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D3
			hps_io_hps_io_usb1_inst_D4      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D4
			hps_io_hps_io_usb1_inst_D5      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D5
			hps_io_hps_io_usb1_inst_D6      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D6
			hps_io_hps_io_usb1_inst_D7      : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D7
			hps_io_hps_io_usb1_inst_CLK     : in    std_logic                     := 'X';             -- hps_io_usb1_inst_CLK
			hps_io_hps_io_usb1_inst_STP     : out   std_logic;                                        -- hps_io_usb1_inst_STP
			hps_io_hps_io_usb1_inst_DIR     : in    std_logic                     := 'X';             -- hps_io_usb1_inst_DIR
			hps_io_hps_io_usb1_inst_NXT     : in    std_logic                     := 'X';             -- hps_io_usb1_inst_NXT
			hps_io_hps_io_uart0_inst_RX     : in    std_logic                     := 'X';             -- hps_io_uart0_inst_RX
			hps_io_hps_io_uart0_inst_TX     : out   std_logic;                                        -- hps_io_uart0_inst_TX
			hps_io_hps_io_i2c0_inst_SDA     : inout std_logic                     := 'X';             -- hps_io_i2c0_inst_SDA
			hps_io_hps_io_i2c0_inst_SCL     : inout std_logic                     := 'X';             -- hps_io_i2c0_inst_SCL
			hps_io_hps_io_i2c1_inst_SDA     : inout std_logic                     := 'X';             -- hps_io_i2c1_inst_SDA
			hps_io_hps_io_i2c1_inst_SCL     : inout std_logic                     := 'X';             -- hps_io_i2c1_inst_SCL
			hps_io_hps_io_can0_inst_RX      : in    std_logic                     := 'X';             -- hps_io_can0_inst_RX
			hps_io_hps_io_can0_inst_TX      : out   std_logic;                                        -- hps_io_can0_inst_TX
			hps_io_hps_io_can1_inst_RX      : in    std_logic                     := 'X';             -- hps_io_can1_inst_RX
			hps_io_hps_io_can1_inst_TX      : out   std_logic;                                        -- hps_io_can1_inst_TX
			hps_io_hps_io_gpio_inst_GPIO00  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO00
			hps_io_hps_io_gpio_inst_GPIO09  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO09
			hps_io_hps_io_gpio_inst_GPIO28  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO28
			hps_io_hps_io_gpio_inst_GPIO37  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO37
			hps_io_hps_io_gpio_inst_GPIO40  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO40
			hps_io_hps_io_gpio_inst_GPIO41  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO41
			hps_io_hps_io_gpio_inst_GPIO48  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO48
			hps_io_hps_io_gpio_inst_GPIO49  : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO49
			hps_io_hps_io_gpio_inst_GPIO50  : inout std_logic                     := 'X'              -- hps_io_gpio_inst_GPIO50
		);
	end component mityarm_5csx_dev_board;
	
	component issp IS
		port
		(
			probe		: in std_logic_vector (42 DOWNTO 0);
			source	: out std_logic_vector (41 DOWNTO 0)
		);
	end component issp;
begin  -- architecture rtl
   ----------------------------------------------------------------------------
   -- Component instantiations
   ----------------------------------------------------------------------------
	issp0 : component issp
		port map
		(
			probe(0) => HSMC1_RX0,
			probe(1) => HSMC1_RX1,
			probe(2) => HSMC1_RX2,
			probe(3) => HSMC1_RX3,
			probe(4) => HSMC1_RX4,
			probe(5) => HSMC1_RX5,
			probe(6) => HSMC1_RX6,
			probe(7) => HSMC1_RX7,
			probe(8) => HSMC1_RX8,
			probe(9) => HSMC1_RX9,
			probe(10) => HSMC1_RX10,
			probe(11) => HSMC1_RX11,
			probe(12) => HSMC1_RX12,
			probe(13) => HSMC1_RX13,
			probe(14) => HSMC1_RX14,
			probe(15) => HSMC1_RX15,
			probe(16) => HSMC1_RX16,
			probe(17) => HSMC1_RX0_N,
			probe(18) => HSMC1_RX1_N,
			probe(19) => HSMC1_RX2_N,
			probe(20) => HSMC1_RX3_N,
			probe(21) => HSMC1_RX4_N,
			probe(22) => HSMC1_RX5_N,
			probe(23) => HSMC1_RX6_N,
			probe(24) => HSMC1_RX7_N,
			probe(25) => HSMC1_RX8_N,
			probe(26) => HSMC1_RX9_N,
			probe(27) => HSMC1_RX10_N,
			probe(28) => HSMC1_RX11_N,
			probe(29) => HSMC1_RX12_N,
			probe(30) => HSMC1_RX13_N,
			probe(31) => HSMC1_RX14_N,
			probe(32) => HSMC1_RX15_N,
			probe(33) => HSMC1_RX16_N,
			probe(34) => HSMC1_SMSDA,
			probe(35) => HSMC1_CLKIN0,
			probe(36) => HSMC1_CLKIN1,
			probe(37) => HSMC1_CLKIN2,
			probe(38) => HSMC1_CLKIN1_N,
			probe(39) => HSMC1_CLKIN2_N,
			probe(40) => HSMC1_D1,
			probe(41) => HSMC1_D3,
			probe(42) => HSMC1_PRSNTn,
			source(0) => HSMC1_TX0,
			source(1) => HSMC1_TX1,
			source(2) => HSMC1_TX2,
			source(3) => HSMC1_TX3,
			source(4) => HSMC1_TX4,
			source(5) => HSMC1_TX5,
			source(6) => HSMC1_TX6,
			source(7) => HSMC1_TX7,
			source(8) => HSMC1_TX8,
			source(9) => HSMC1_TX9,
			source(10) => HSMC1_TX10,
			source(11) => HSMC1_TX11,
			source(12) => HSMC1_TX12,
			source(13) => HSMC1_TX13,
			source(14) => HSMC1_TX14,
			source(15) => HSMC1_TX15,
			source(16) => HSMC1_TX16,
			source(17) => HSMC1_TX0_N,
			source(18) => HSMC1_TX1_N,
			source(19) => HSMC1_TX2_N,
			source(20) => HSMC1_TX3_N,
			source(21) => HSMC1_TX4_N,
			source(22) => HSMC1_TX5_N,
			source(23) => HSMC1_TX6_N,
			source(24) => HSMC1_TX7_N,
			source(25) => HSMC1_TX8_N,
			source(26) => HSMC1_TX9_N,
			source(27) => HSMC1_TX10_N,
			source(28) => HSMC1_TX11_N,
			source(29) => HSMC1_TX12_N,
			source(30) => HSMC1_TX13_N,
			source(31) => HSMC1_TX14_N,
			source(32) => HSMC1_TX15_N,
			source(33) => HSMC1_TX16_N,
			source(34) => HSMC1_SMSCL,
			source(35) => HSMC1_CLKOUT0,
			source(36) => HSMC1_CLKOUT1,
			source(37) => HSMC1_CLKOUT2,
			source(38) => HSMC1_CLKOUT1_N,
			source(39) => HSMC1_CLKOUT2_N,
			source(40) => HSMC1_D0,
			source(41) => HSMC1_D2
		);
		 
u0 : component mityarm_5csx_dev_board
		port map (
			hps_ddr_mem_a                   => HPS_DDR_A,                   -- hps_ddr.mem_a
			hps_ddr_mem_ba                  => HPS_DDR_BAS,                  --       .mem_ba
			hps_ddr_mem_ck                  => HPS_DDR_CK_P,                  --       .mem_ck
			hps_ddr_mem_ck_n                => HPS_DDR_CK_N,                --       .mem_ck_n
			hps_ddr_mem_cke                 => HPS_DDR_CKE,                 --       .mem_cke
			hps_ddr_mem_cs_n                => HPS_DDR_CS0_N,                --       .mem_cs_n
			hps_ddr_mem_ras_n               => HPS_DDR_RAS_N,               --       .mem_ras_n
			hps_ddr_mem_cas_n               => HPS_DDR_CAS_N,               --       .mem_cas_n
			hps_ddr_mem_we_n                => HPS_DDR_WE_N,                --       .mem_we_n
			hps_ddr_mem_reset_n             => HPS_DDR_RESET_N,             --       .mem_reset_n
			hps_ddr_mem_dq                  => HPS_DDR_D,                  --       .mem_dq
			hps_ddr_mem_dqs                 => HPS_DDR_DQS_P,                 --       .mem_dqs
			hps_ddr_mem_dqs_n               => HPS_DDR_DQS_N,               --       .mem_dqs_n
			hps_ddr_mem_odt                 => HPS_ODT,                 --       .mem_odt
			hps_ddr_mem_dm                  => HPS_DDR_DQM,                  --       .mem_dm
			hps_ddr_oct_rzqin               => HPS_RZQ0,               --       .oct_rzqin
			hps_io_hps_io_emac1_inst_TX_CLK => RGMII1_TX_CLK, -- hps_io.hps_io_emac1_inst_TX_CLK
			hps_io_hps_io_emac1_inst_TXD0   => RGMII1_TXD0,   --       .hps_io_emac1_inst_TXD0
			hps_io_hps_io_emac1_inst_TXD1   => RGMII1_TXD1,   --       .hps_io_emac1_inst_TXD1
			hps_io_hps_io_emac1_inst_TXD2   => RGMII1_TXD2,   --       .hps_io_emac1_inst_TXD2
			hps_io_hps_io_emac1_inst_TXD3   => RGMII1_TXD3,   --       .hps_io_emac1_inst_TXD3
			hps_io_hps_io_emac1_inst_RXD0   => RGMII1_RXD0,   --       .hps_io_emac1_inst_RXD0
			hps_io_hps_io_emac1_inst_RXD1   => RGMII1_RXD1,   --       .hps_io_emac1_inst_RXD1
			hps_io_hps_io_emac1_inst_RXD2   => RGMII1_RXD2,   --       .hps_io_emac1_inst_RXD2
			hps_io_hps_io_emac1_inst_RXD3   => RGMII1_RXD3,   --       .hps_io_emac1_inst_RXD3
			hps_io_hps_io_emac1_inst_MDIO   => RGMII1_MDIO,   --       .hps_io_emac1_inst_MDIO
			hps_io_hps_io_emac1_inst_MDC    => RGMII1_MDC,    --       .hps_io_emac1_inst_MDC
			hps_io_hps_io_emac1_inst_RX_CTL => RGMII1_RX_CTL, --       .hps_io_emac1_inst_RX_CTL
			hps_io_hps_io_emac1_inst_TX_CTL => RGMII1_TX_CTL, --       .hps_io_emac1_inst_TX_CTL
			hps_io_hps_io_emac1_inst_RX_CLK => RGMII1_RX_CLK, --       .hps_io_emac1_inst_RX_CLK
			hps_io_hps_io_qspi_inst_SS1    => QSPI_SS1,    -- hps_io.hps_io_qspi_inst_SS1
			hps_io_hps_io_qspi_inst_IO0    => QSPI_DQ0,    --       .hps_io_qspi_inst_IO0
			hps_io_hps_io_qspi_inst_IO1    => QSPI_DQ1,    --       .hps_io_qspi_inst_IO1
			hps_io_hps_io_qspi_inst_IO2    => QSPI_DQ2,    --       .hps_io_qspi_inst_IO2
			hps_io_hps_io_qspi_inst_IO3    => QSPI_DQ3,    --       .hps_io_qspi_inst_IO3
			hps_io_hps_io_qspi_inst_SS0    => QSPI_SS0,    --       .hps_io_qspi_inst_SS0
			hps_io_hps_io_qspi_inst_CLK    => QSPI_CLK,    --       .hps_io_qspi_inst_CLK
			hps_io_hps_io_sdio_inst_CMD     => SDMMC_CMD,     --       .hps_io_sdio_inst_CMD
			hps_io_hps_io_sdio_inst_D0      => SDMMC_D0,      --       .hps_io_sdio_inst_D0
			hps_io_hps_io_sdio_inst_D1      => SDMMC_D1,      --       .hps_io_sdio_inst_D1
			hps_io_hps_io_sdio_inst_D2      => SDMMC_D2,      --       .hps_io_sdio_inst_D2
			hps_io_hps_io_sdio_inst_D3      => SDMMC_D3,      --       .hps_io_sdio_inst_D3
			hps_io_hps_io_sdio_inst_CLK     => SDMMC_CLK,     --       .hps_io_sdio_inst_CLK
			hps_io_hps_io_usb1_inst_D0     => USB1_ULPI_D0,     --       .hps_io_usb1_inst_D0
			hps_io_hps_io_usb1_inst_D1     => USB1_ULPI_D1,     --       .hps_io_usb1_inst_D1
			hps_io_hps_io_usb1_inst_D2     => USB1_ULPI_D2,     --       .hps_io_usb1_inst_D2
			hps_io_hps_io_usb1_inst_D3     => USB1_ULPI_D3,     --       .hps_io_usb1_inst_D3
			hps_io_hps_io_usb1_inst_D4     => USB1_ULPI_D4,     --       .hps_io_usb1_inst_D4
			hps_io_hps_io_usb1_inst_D5     => USB1_ULPI_D5,     --       .hps_io_usb1_inst_D5
			hps_io_hps_io_usb1_inst_D6     => USB1_ULPI_D6,     --       .hps_io_usb1_inst_D6
			hps_io_hps_io_usb1_inst_D7     => USB1_ULPI_D7,     --       .hps_io_usb1_inst_D7
			hps_io_hps_io_usb1_inst_CLK    => USB1_ULPI_CLK,    --       .hps_io_usb1_inst_CLK
			hps_io_hps_io_usb1_inst_STP    => USB1_ULPI_STP,    --       .hps_io_usb1_inst_STP
			hps_io_hps_io_usb1_inst_DIR    => USB1_ULPI_DIR,    --       .hps_io_usb1_inst_DIR
			hps_io_hps_io_usb1_inst_NXT    => USB1_ULPI_NXT,    --       .hps_io_usb1_inst_NXT
			hps_io_hps_io_uart0_inst_RX    => B7A_UART0_RX,    --       .hps_io_uart0_inst_RX
			hps_io_hps_io_uart0_inst_TX    => B7A_UART0_TX,    --       .hps_io_uart0_inst_TX
			hps_io_hps_io_i2c0_inst_SDA    => B7A_I2C0_SDA,    --       .hps_io_i2c0_inst_SDA
			hps_io_hps_io_i2c0_inst_SCL    => B7A_I2C0_SCL,    --       .hps_io_i2c0_inst_SCL
         hps_io_hps_io_i2c1_inst_SDA    => I2C1_SDA,          -- hps_io_i2c1_inst_SDA
         hps_io_hps_io_i2c1_inst_SCL    => I2C1_SCL,          -- hps_io_i2c1_inst_SCL
			hps_io_hps_io_can0_inst_RX      => B7A_CAN0_RX,      --       .hps_io_can0_inst_RX
			hps_io_hps_io_can0_inst_TX      => B7a_CAN0_TX,      --       .hps_io_can0_inst_TX
			hps_io_hps_io_can1_inst_RX      => B7A_CAN1_RX,      --       .hps_io_can1_inst_RX
			hps_io_hps_io_can1_inst_TX      => B7A_CAN1_TX,      --       .hps_io_can1_inst_TX
			hps_io_hps_io_gpio_inst_GPIO00 => USB1_ULPI_CS, --       .hps_io_gpio_inst_GPIO00
			hps_io_hps_io_gpio_inst_GPIO09 => USB1_ULPI_RESET_N,  --       .hps_io_gpio_inst_GPIO09
			hps_io_hps_io_gpio_inst_GPIO48  => RGMII1_RESETn,   --       .hps_io_gpio_inst_GPIO48
         hps_io_hps_io_gpio_inst_GPIO28  => LED3,           -- hps_io_gpio_inst_GPIO28
         hps_io_hps_io_gpio_inst_GPIO37  => SW1,            -- hps_io_gpio_inst_GPIO37
         hps_io_hps_io_gpio_inst_GPIO40  => SW2,            -- hps_io_gpio_inst_GPIO40
         hps_io_hps_io_gpio_inst_GPIO41  => SW3,             -- hps_io_gpio_inst_GPIO41
         hps_io_hps_io_gpio_inst_GPIO49  => LED2,            -- hps_io_gpio_inst_GPIO49
         hps_io_hps_io_gpio_inst_GPIO50  => LED1             -- hps_io_gpio_inst_GPIO50
		);
   
end architecture rtl;

-------------------------------------------------------------------------------
